Complete API Reference
======================

This page contains the complete API reference for all oduit modules.

.. automodule:: oduit
   :members:
   :undoc-members:
   :show-inheritance:

Core Classes
------------

ProcessManager
~~~~~~~~~~~~~~

.. autoclass:: oduit.ProcessManager
   :members:
   :undoc-members:
   :show-inheritance:

ConfigLoader
~~~~~~~~~~~~

.. autoclass:: oduit.ConfigLoader
   :members:
   :undoc-members:
   :show-inheritance:

OdooOperations
~~~~~~~~~~~~~~

.. autoclass:: oduit.OdooOperations
   :members:
   :undoc-members:
   :show-inheritance:

ModuleManager
~~~~~~~~~~~~~

.. autoclass:: oduit.ModuleManager
   :members:
   :undoc-members:
   :show-inheritance:

DemoProcessManager
~~~~~~~~~~~~~~~~~~

.. autoclass:: oduit.DemoProcessManager
   :members:
   :undoc-members:
   :show-inheritance:

Utility Classes
---------------

OperationResult
~~~~~~~~~~~~~~~

.. autoclass:: oduit.OperationResult
   :members:
   :undoc-members:
   :show-inheritance:

OutputFormatter
~~~~~~~~~~~~~~~

.. autoclass:: oduit.OutputFormatter
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: oduit.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
